using data.Domain.UseCase;
using data.RemoteData.RemoteDataBase;
using data.Repository;
using Microsoft.EntityFrameworkCore;

var builder = WebApplication.CreateBuilder(args);

//      
builder.Services.AddDbContext<RemoteDatabaseContext>(); //   

//    UseCase
builder.Services.AddScoped<IUserRepository, SQLUserRepositoryImpl>()
                .AddScoped<IPresenceRepository, SQLPresenceRepositoryImpl>()
                .AddScoped<IGroupRepository, SQLGroupRepositoryImpl>()
                .AddScoped<UseCaseGeneratePresence>()
                .AddScoped<GroupUseCase>();


//  
builder.Services.AddControllers();

//  Swagger  API 
builder.Services.AddEndpointsApiExplorer(); //   OpenAPI 
builder.Services.AddSwaggerGen(); //   Swagger

var app = builder.Build();

//  Swagger UI  
if (app.Environment.IsDevelopment())
{
    app.UseSwagger(); //  Swagger
    app.UseSwaggerUI(); //  Swagger UI
}

//  Middleware
app.UseHttpsRedirection(); //   HTTPS
app.MapControllers(); //   

app.Run(); //  
